<?php
namespace Ak\Task;

use Laminas\ConfigAggregator\ConfigAggregator;
use Laminas\ConfigAggregator\PhpFileProvider;

/**
 * Pruža konfiguraciju komponente.
 *
 * @package Ak\Task
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/task
 */
final class ConfigProvider
{
    public function __invoke(): array
    {
        return [
            'routes' => $this->getRoutes(),

            'orm' => [
                'entity_paths' => [
                    __NAMESPACE__ => __DIR__,
                ],
            ],

            'view' => [
                'script_paths' => [
                    __DIR__ . '/../view',
                ],
            ],
        ];
    }

    public function getRoutes(): array
    {
        return [
            'task-manager' => [
                'path' => '/task-manager',
                'middleware' => Handler\Index::class,
                'methods' => ['GET'],
            ],

            'task-manager.run' => [
                'path' => '/task-manager/run/:id',
                'middleware' => Handler\Run::class,
                'methods' => ['GET'],
            ],

            'task-manager.create' => [
                'path' => '/task-manager/new/:type',
                'middleware' => Handler\Create::class,
                'methods' => ['GET', 'POST'],
            ],

            'task-manager.edit' => [
                'path' => '/task-manager/edit/:id',
                'middleware' => Handler\Edit::class,
                'methods' => ['GET', 'POST'],
            ],

            'task-manager.delete' => [
                'path' => '/task-manager/delete/:id',
                'middleware' => Handler\Delete::class,
                'methods' => ['GET', 'POST'],
            ],

            'task-manager.details' => [
                'path' => '/task-manager/details/:id',
                'middleware' => Handler\Details::class,
                'allowed_methods' => ['GET'],
            ],
        ];
    }

    /**
     * @return array
     */
    public function getOrmConfig(): array
    {
        return [
            'entity_paths' => [
                __NAMESPACE__ => __DIR__,
            ],
        ];
    }
}
