<?php
namespace Ak\Task\Handler;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\RedirectResponse;

/**
 * Class Create
 *
 * @package Ak\Task\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/task
 */
final class Create extends AbstractHandler
{
    /**
     * Handles a request and produces a response.
     *
     * May call other collaborating code to generate the response.
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        $type = $request->getAttribute('type');
        $taskClass = $this->config['tasks'][$type]['entity_class'];

        $task = new $taskClass;
        $form = $this->getForm($task);

        if ($request->getMethod() === 'POST') {
            $form->bindValues($request->getParsedBody());

            if ($form->isValid()) {
                $this->em->persist($task);

                return new RedirectResponse(
                    $this->urlHelper->generate('task-manager')
                );
            }
        }

        return new HtmlResponse(
            $this->render('task-manager/form', [
                'title' => 'Novi zadatak',
                'form' => $form,
            ])
        );
    }
}
