<?php
namespace Ak\Task\Handler;

use Ak\Task\Task;
use Ak\Task\TaskInterface;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Laminas\Diactoros\Response\HtmlResponse;
use Laminas\Diactoros\Response\RedirectResponse;

/**
 * Class Edit
 *
 * @package Ak\Task\Handler
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/task
 */
final class Edit extends AbstractHandler
{
    /**
     * Handles a request and produces a response.
     *
     * May call other collaborating code to generate the response.
     *
     * @param ServerRequestInterface $request
     * @return ResponseInterface
     */
    public function handle(ServerRequestInterface $request): ResponseInterface
    {
        $id = $request->getAttribute('id');
        /** @var TaskInterface $task */
        $task = $this->em->find(Task::class, $id);
        $form = $this->getForm($task);

        if ($request->getMethod() === 'POST') {
            $form->bindValues($request->getParsedBody());

            if ($form->isValid()) {
                $this->em->persist($task);

                return new RedirectResponse(
                    $this->urlHelper->generate('task-manager')
                );
            }
        }

        return new HtmlResponse(
            $this->render('task-manager/form', [
                'title' => $task->getName(),
                'form' => $form,
            ])
        );
    }
}
