<?php
namespace Ak\Task;

use Ak\Orm\Entity\AbstractEntity;
use Ak\Orm\Entity\TimestampableTrait;
use Ak\Orm\Mapping\DiscriminatorEntry;
use Doctrine\ORM\Mapping as ORM;
use Laminas\Form\Annotation as Form;

/**
 * Zadatak.
 *
 * @package Ak\Task
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/task
 *
 * @ORM\Entity()
 * @ORM\InheritanceType("SINGLE_TABLE")
 * @ORM\DiscriminatorColumn(name="type")
 * @DiscriminatorEntry("task")
 * @ORM\Table(name="task", options={"charset": "utf8mb4", "collate": "utf8mb4_general_ci"})
 * @Form\Type("Ak\Task\Form\TaskForm")
 */
class Task extends AbstractEntity implements TaskInterface
{
    use TimestampableTrait;

    /**
     * @var string
     *
     * @ORM\Column(type="string")
     * @Form\Options({"label": "Naziv zadatka"})
     * @Form\Flags({"priority": 100})
     * @Form\Validator("notempty", {
     *     "messages": {"isEmpty": "Naziv zadatka je obavezan"}
     * })
     */
    protected $name;

    /**
     * @var string
     *
     * @ORM\Column(type="string", options={"default": "stopped"})
     * @Form\Exclude()
     */
    protected $status = self::STATUS_STOPPED;

    /**
     * @var object
     *
     * @ORM\Column(type="hydrated_object", nullable=true)
     * @Form\Options({"label": "Postavke"})
     */
    protected $params;

    /**
     * @return string
     */
    public function getName(): string
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName(string $name): void
    {
        $this->name = $name;
    }

    /**
     * @return object
     */
    public function getParams(): ?object
    {
        return $this->params;
    }

    /**
     * Pokreće ovaj zadatak.
     */
    public function run(): void
    { }
}
