<?php
namespace AkTest\Task;

use Ak\Form\FormElementManager;
use Ak\Orm\Form\EntityForm;
use Ak\Task\Task;
use AkMock\Task\CustomTask;
use Laminas\Form\Fieldset;
use Laminas\InputFilter\Input;

/**
 * Class TaskFormTest
 *
 * @package AkTest\Task
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link https://bitbucket.org/autokreso/task
 */
final class TaskFormTest extends AbstractTestCase
{
    protected function getForm(string $entity = Task::class): EntityForm
    {
        $container = $this->getContainer();
        /** @var FormElementManager $forms */
        $forms = $container->get(FormElementManager::class);
        /** @noinspection PhpIncompatibleReturnTypeInspection */
        return $forms->get($entity);
    }

    public function testFormCanBeCreated()
    {
        $form = $this->getForm();

        $this->assertTrue($form->has('name'));
        $this->assertFalse($form->has('params'));
    }

    public function testFormCanHaveParams()
    {
        $form = $this->getForm(CustomTask::class);

        $this->assertTrue($form->has('params'));

        /** @var Fieldset $params */
        $params = $form->get('params');
        $this->assertNotEmpty($params->getLabel());
        $this->assertInstanceOf(Fieldset::class, $params);

        $this->assertTrue($params->has('name'));
        $this->assertTrue($params->has('value'));
    }

    public function testNameIsTheFirstField()
    {
        $form = $this->getForm(CustomTask::class);

        foreach ($form as $element) {
            $this->assertTrue($element->getName() === 'name');
            break;
        }
    }

    public function testNameIsRequired()
    {
        $form = $this->getForm();
        $filter = $form->getInputFilter();

        $this->assertTrue($filter->has('name'));
        /** @var Input $name */
        $name = $filter->get('name');

        $this->assertTrue($name->isRequired());
    }
}
